Class: Aws::ChimeSDKMessaging::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ChimeSDKMessaging::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-chimesdkmessaging/client.rb,
sig/client.rbs
Overview
An API client for ChimeSDKMessaging. To construct a client, you need to configure a :region and :credentials.
client = Aws::ChimeSDKMessaging::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchCreateChannelMembershipResponseSuccess, _ChannelFlowCallbackResponseSuccess, _CreateChannelBanResponseSuccess, _CreateChannelFlowResponseSuccess, _CreateChannelMembershipResponseSuccess, _CreateChannelModeratorResponseSuccess, _CreateChannelResponseSuccess, _DescribeChannelBanResponseSuccess, _DescribeChannelFlowResponseSuccess, _DescribeChannelMembershipForAppInstanceUserResponseSuccess, _DescribeChannelMembershipResponseSuccess, _DescribeChannelModeratedByAppInstanceUserResponseSuccess, _DescribeChannelModeratorResponseSuccess, _DescribeChannelResponseSuccess, _GetChannelMembershipPreferencesResponseSuccess, _GetChannelMessageResponseSuccess, _GetChannelMessageStatusResponseSuccess, _GetMessagingSessionEndpointResponseSuccess, _GetMessagingStreamingConfigurationsResponseSuccess, _ListChannelBansResponseSuccess, _ListChannelFlowsResponseSuccess, _ListChannelMembershipsForAppInstanceUserResponseSuccess, _ListChannelMembershipsResponseSuccess, _ListChannelMessagesResponseSuccess, _ListChannelModeratorsResponseSuccess, _ListChannelsAssociatedWithChannelFlowResponseSuccess, _ListChannelsModeratedByAppInstanceUserResponseSuccess, _ListChannelsResponseSuccess, _ListSubChannelsResponseSuccess, _ListTagsForResourceResponseSuccess, _PutChannelExpirationSettingsResponseSuccess, _PutChannelMembershipPreferencesResponseSuccess, _PutMessagingStreamingConfigurationsResponseSuccess, _RedactChannelMessageResponseSuccess, _SearchChannelsResponseSuccess, _SendChannelMessageResponseSuccess, _UpdateChannelFlowResponseSuccess, _UpdateChannelMessageResponseSuccess, _UpdateChannelReadMarkerResponseSuccess, _UpdateChannelResponseSuccess
Constant Summary collapse
- Params =
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_channel_flow(params = {}) ⇒ Struct
Associates a channel flow with a channel.
-
#batch_create_channel_membership(params = {}) ⇒ Types::BatchCreateChannelMembershipResponse
Adds a specified number of users and bots to a channel.
-
#channel_flow_callback(params = {}) ⇒ Types::ChannelFlowCallbackResponse
Calls back Amazon Chime SDK messaging with a processing response message.
-
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a channel to which you can add users and send messages.
-
#create_channel_ban(params = {}) ⇒ Types::CreateChannelBanResponse
Permanently bans a member from a channel.
-
#create_channel_flow(params = {}) ⇒ Types::CreateChannelFlowResponse
Creates a channel flow, a container for processors.
-
#create_channel_membership(params = {}) ⇒ Types::CreateChannelMembershipResponse
Adds a member to a channel.
-
#create_channel_moderator(params = {}) ⇒ Types::CreateChannelModeratorResponse
Creates a new
ChannelModerator. -
#delete_channel(params = {}) ⇒ Struct
Immediately makes a channel and its memberships inaccessible and marks them for deletion.
-
#delete_channel_ban(params = {}) ⇒ Struct
Removes a member from a channel's ban list.
-
#delete_channel_flow(params = {}) ⇒ Struct
Deletes a channel flow, an irreversible process.
-
#delete_channel_membership(params = {}) ⇒ Struct
Removes a member from a channel.
-
#delete_channel_message(params = {}) ⇒ Struct
Deletes a channel message.
-
#delete_channel_moderator(params = {}) ⇒ Struct
Deletes a channel moderator.
-
#delete_messaging_streaming_configurations(params = {}) ⇒ Struct
Deletes the streaming configurations for an
AppInstance. -
#describe_channel(params = {}) ⇒ Types::DescribeChannelResponse
Returns the full details of a channel in an Amazon Chime
AppInstance. -
#describe_channel_ban(params = {}) ⇒ Types::DescribeChannelBanResponse
Returns the full details of a channel ban.
-
#describe_channel_flow(params = {}) ⇒ Types::DescribeChannelFlowResponse
Returns the full details of a channel flow in an Amazon Chime
AppInstance. -
#describe_channel_membership(params = {}) ⇒ Types::DescribeChannelMembershipResponse
Returns the full details of a user's channel membership.
-
#describe_channel_membership_for_app_instance_user(params = {}) ⇒ Types::DescribeChannelMembershipForAppInstanceUserResponse
Returns the details of a channel based on the membership of the specified
AppInstanceUserorAppInstanceBot. -
#describe_channel_moderated_by_app_instance_user(params = {}) ⇒ Types::DescribeChannelModeratedByAppInstanceUserResponse
Returns the full details of a channel moderated by the specified
AppInstanceUserorAppInstanceBot. -
#describe_channel_moderator(params = {}) ⇒ Types::DescribeChannelModeratorResponse
Returns the full details of a single ChannelModerator.
-
#disassociate_channel_flow(params = {}) ⇒ Struct
Disassociates a channel flow from all its channels.
-
#get_channel_membership_preferences(params = {}) ⇒ Types::GetChannelMembershipPreferencesResponse
Gets the membership preferences of an
AppInstanceUserorAppInstanceBotfor the specified channel. -
#get_channel_message(params = {}) ⇒ Types::GetChannelMessageResponse
Gets the full details of a channel message.
-
#get_channel_message_status(params = {}) ⇒ Types::GetChannelMessageStatusResponse
Gets message status for a specified
messageId. -
#get_messaging_session_endpoint(params = {}) ⇒ Types::GetMessagingSessionEndpointResponse
The details of the endpoint for the messaging session.
-
#get_messaging_streaming_configurations(params = {}) ⇒ Types::GetMessagingStreamingConfigurationsResponse
Retrieves the data streaming configuration for an
AppInstance. -
#list_channel_bans(params = {}) ⇒ Types::ListChannelBansResponse
Lists all the users and bots banned from a particular channel.
-
#list_channel_flows(params = {}) ⇒ Types::ListChannelFlowsResponse
Returns a paginated lists of all the channel flows created under a single Chime.
-
#list_channel_memberships(params = {}) ⇒ Types::ListChannelMembershipsResponse
Lists all channel memberships in a channel.
-
#list_channel_memberships_for_app_instance_user(params = {}) ⇒ Types::ListChannelMembershipsForAppInstanceUserResponse
Lists all channels that an
AppInstanceUserorAppInstanceBotis a part of. -
#list_channel_messages(params = {}) ⇒ Types::ListChannelMessagesResponse
List all the messages in a channel.
-
#list_channel_moderators(params = {}) ⇒ Types::ListChannelModeratorsResponse
Lists all the moderators for a channel.
-
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Lists all Channels created under a single Chime App as a paginated list.
-
#list_channels_associated_with_channel_flow(params = {}) ⇒ Types::ListChannelsAssociatedWithChannelFlowResponse
Lists all channels associated with a specified channel flow.
-
#list_channels_moderated_by_app_instance_user(params = {}) ⇒ Types::ListChannelsModeratedByAppInstanceUserResponse
A list of the channels moderated by an
AppInstanceUser. -
#list_sub_channels(params = {}) ⇒ Types::ListSubChannelsResponse
Lists all the SubChannels in an elastic channel when given a channel ID.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags applied to an Amazon Chime SDK messaging resource.
-
#put_channel_expiration_settings(params = {}) ⇒ Types::PutChannelExpirationSettingsResponse
Sets the number of days before the channel is automatically deleted.
-
#put_channel_membership_preferences(params = {}) ⇒ Types::PutChannelMembershipPreferencesResponse
Sets the membership preferences of an
AppInstanceUserorAppInstanceBotfor the specified channel. -
#put_messaging_streaming_configurations(params = {}) ⇒ Types::PutMessagingStreamingConfigurationsResponse
Sets the data streaming configuration for an
AppInstance. -
#redact_channel_message(params = {}) ⇒ Types::RedactChannelMessageResponse
Redacts message content and metadata.
-
#search_channels(params = {}) ⇒ Types::SearchChannelsResponse
Allows the
ChimeBearerto search channels by channel members. -
#send_channel_message(params = {}) ⇒ Types::SendChannelMessageResponse
Sends a message to a particular channel that the member is a part of.
-
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified Amazon Chime SDK messaging resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified Amazon Chime SDK messaging resource.
-
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Update a channel's attributes.
-
#update_channel_flow(params = {}) ⇒ Types::UpdateChannelFlowResponse
Updates channel flow attributes.
-
#update_channel_message(params = {}) ⇒ Types::UpdateChannelMessageResponse
Updates the content of a message.
-
#update_channel_read_marker(params = {}) ⇒ Types::UpdateChannelReadMarkerResponse
The details of the time when a user last read messages in a channel.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3342 3343 3344 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3342 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3345 3346 3347 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3345 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14 def self.new: ( |
Instance Method Details
#associate_channel_flow(params = {}) ⇒ Struct
Associates a channel flow with a channel. Once associated, all
messages to that channel go through channel flow processors. To stop
processing, use the DisassociateChannelFlow API.
x-amz-chime-bearer request header is mandatory. Use the
ARN of the AppInstanceUser or AppInstanceBot that makes the API
call as the value in the header.
82 |
# File 'sig/client.rbs', line 82 def associate_channel_flow: ( |
#batch_create_channel_membership(params = {}) ⇒ Types::BatchCreateChannelMembershipResponse
Adds a specified number of users and bots to a channel.
95 |
# File 'sig/client.rbs', line 95 def batch_create_channel_membership: ( |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3315 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ChimeSDKMessaging') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-chimesdkmessaging' context[:gem_version] = '1.69.0' Seahorse::Client::Request.new(handlers, context) end |
#channel_flow_callback(params = {}) ⇒ Types::ChannelFlowCallbackResponse
Calls back Amazon Chime SDK messaging with a processing response message. This should be invoked from the processor Lambda. This is a developer API.
You can return one of the following processing responses:
-
Update message content or metadata
-
Deny a message
-
Make no changes to the message
110 |
# File 'sig/client.rbs', line 110 def channel_flow_callback: ( |
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a channel to which you can add users and send messages.
Restriction: You can't change a channel's privacy.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
137 |
# File 'sig/client.rbs', line 137 def create_channel: ( |
#create_channel_ban(params = {}) ⇒ Types::CreateChannelBanResponse
Permanently bans a member from a channel. Moderators can't add banned
members to a channel. To undo a ban, you first have to
DeleteChannelBan, and then CreateChannelMembership. Bans are
cleaned up when you delete users or channels.
If you ban a user who is already part of a channel, that user is automatically kicked from the channel.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
172 |
# File 'sig/client.rbs', line 172 def create_channel_ban: ( |
#create_channel_flow(params = {}) ⇒ Types::CreateChannelFlowResponse
Creates a channel flow, a container for processors. Processors are AWS Lambda functions that perform actions on chat messages, such as stripping out profanity. You can associate channel flows with channels, and the processors in the channel flow then take action on all messages sent to that channel. This is a developer API.
Channel flows process the following items:
-
New and updated messages
-
Persistent and non-persistent messages
-
The Standard message type
184 |
# File 'sig/client.rbs', line 184 def create_channel_flow: ( |
#create_channel_membership(params = {}) ⇒ Types::CreateChannelMembershipResponse
Adds a member to a channel. The InvitedBy field in
ChannelMembership is derived from the request header. A channel
member can:
-
List messages
-
Send messages
-
Receive messages
-
Edit their own messages
-
Leave the channel
Privacy settings impact this action as follows:
-
Public Channels: You do not need to be a member to list messages, but you must be a member to send messages.
-
Private Channels: You must be a member to list or send messages.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUserArn or AppInstanceBot that makes the API call
as the value in the header.
207 |
# File 'sig/client.rbs', line 207 def create_channel_membership: ( |
#create_channel_moderator(params = {}) ⇒ Types::CreateChannelModeratorResponse
Creates a new ChannelModerator. A channel moderator can:
-
Add and remove other members of the channel.
-
Add and remove other moderators of the channel.
-
Add and remove user bans for the channel.
-
Redact messages in the channel.
-
List messages in the channel.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBotof the user that makes the
API call as the value in the header.
222 |
# File 'sig/client.rbs', line 222 def create_channel_moderator: ( |
#delete_channel(params = {}) ⇒ Struct
Immediately makes a channel and its memberships inaccessible and marks them for deletion. This is an irreversible process.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUserArn or AppInstanceBot that makes the API call
as the value in the header.
230 |
# File 'sig/client.rbs', line 230 def delete_channel: ( |
#delete_channel_ban(params = {}) ⇒ Struct
Removes a member from a channel's ban list.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
237 |
# File 'sig/client.rbs', line 237 def delete_channel_ban: ( |
#delete_channel_flow(params = {}) ⇒ Struct
Deletes a channel flow, an irreversible process. This is a developer API.
ListChannelsAssociatedWithChannelFlow API.
Use the DisassociateChannelFlow API to disassociate a channel flow
from all channels.
245 |
# File 'sig/client.rbs', line 245 def delete_channel_flow: ( |
#delete_channel_membership(params = {}) ⇒ Struct
Removes a member from a channel.
x-amz-chime-bearer request header is mandatory. Use the
AppInstanceUserArn of the user that makes the API call as the value
in the header.
251 |
# File 'sig/client.rbs', line 251 def delete_channel_membership: ( |
#delete_channel_message(params = {}) ⇒ Struct
Deletes a channel message. Only admins can perform this action.
Deletion makes messages inaccessible immediately. A background process
deletes any revisions created by UpdateChannelMessage.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
260 |
# File 'sig/client.rbs', line 260 def delete_channel_message: ( |
#delete_channel_moderator(params = {}) ⇒ Struct
Deletes a channel moderator.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
269 |
# File 'sig/client.rbs', line 269 def delete_channel_moderator: ( |
#delete_messaging_streaming_configurations(params = {}) ⇒ Struct
Deletes the streaming configurations for an AppInstance. For more
information, see Streaming messaging data in the Amazon Chime
SDK Developer Guide.
277 |
# File 'sig/client.rbs', line 277 def delete_messaging_streaming_configurations: ( |
#describe_channel(params = {}) ⇒ Types::DescribeChannelResponse
Returns the full details of a channel in an Amazon Chime
AppInstance.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
287 |
# File 'sig/client.rbs', line 287 def describe_channel: ( |
#describe_channel_ban(params = {}) ⇒ Types::DescribeChannelBanResponse
Returns the full details of a channel ban.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
298 |
# File 'sig/client.rbs', line 298 def describe_channel_ban: ( |
#describe_channel_flow(params = {}) ⇒ Types::DescribeChannelFlowResponse
Returns the full details of a channel flow in an Amazon Chime
AppInstance. This is a developer API.
310 |
# File 'sig/client.rbs', line 310 def describe_channel_flow: ( |
#describe_channel_membership(params = {}) ⇒ Types::DescribeChannelMembershipResponse
Returns the full details of a user's channel membership.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
320 |
# File 'sig/client.rbs', line 320 def describe_channel_membership: ( |
#describe_channel_membership_for_app_instance_user(params = {}) ⇒ Types::DescribeChannelMembershipForAppInstanceUserResponse
Returns the details of a channel based on the membership of the
specified AppInstanceUser or AppInstanceBot.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
333 |
# File 'sig/client.rbs', line 333 def describe_channel_membership_for_app_instance_user: ( |
#describe_channel_moderated_by_app_instance_user(params = {}) ⇒ Types::DescribeChannelModeratedByAppInstanceUserResponse
Returns the full details of a channel moderated by the specified
AppInstanceUser or AppInstanceBot.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
345 |
# File 'sig/client.rbs', line 345 def describe_channel_moderated_by_app_instance_user: ( |
#describe_channel_moderator(params = {}) ⇒ Types::DescribeChannelModeratorResponse
Returns the full details of a single ChannelModerator.
x-amz-chime-bearer request header is mandatory. Use the
AppInstanceUserArn of the user that makes the API call as the value
in the header.
357 |
# File 'sig/client.rbs', line 357 def describe_channel_moderator: ( |
#disassociate_channel_flow(params = {}) ⇒ Struct
Disassociates a channel flow from all its channels. Once disassociated, all messages to that channel stop going through the channel flow processor.
The x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
365 |
# File 'sig/client.rbs', line 365 def disassociate_channel_flow: ( |
#get_channel_membership_preferences(params = {}) ⇒ Types::GetChannelMembershipPreferencesResponse
Gets the membership preferences of an AppInstanceUser or
AppInstanceBot for the specified channel. A user or a bot must be a
member of the channel and own the membership in order to retrieve
membership preferences. Users or bots in the AppInstanceAdmin and
channel moderator roles can't retrieve preferences for other users or
bots. Banned users or bots can't retrieve membership preferences for
the channel from which they are banned.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
379 |
# File 'sig/client.rbs', line 379 def get_channel_membership_preferences: ( |
#get_channel_message(params = {}) ⇒ Types::GetChannelMessageResponse
Gets the full details of a channel message.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
391 |
# File 'sig/client.rbs', line 391 def get_channel_message: ( |
#get_channel_message_status(params = {}) ⇒ Types::GetChannelMessageStatusResponse
Gets message status for a specified messageId. Use this API to
determine the intermediate status of messages going through channel
flow processing. The API provides an alternative to retrieving message
status if the event was not received because a client wasn't
connected to a websocket.
Messages can have any one of these statuses.
SENT
: Message processed successfully
PENDING
: Ongoing processing
FAILED
: Processing failed
DENIED
: Message denied by the processor
-
Only the message sender can invoke this API.
-
The
x-amz-chime-bearerrequest header is mandatory. Use the ARN of theAppInstanceUserorAppInstanceBotthat makes the API call as the value in the header.
404 |
# File 'sig/client.rbs', line 404 def get_channel_message_status: ( |
#get_messaging_session_endpoint(params = {}) ⇒ Types::GetMessagingSessionEndpointResponse
The details of the endpoint for the messaging session.
417 |
# File 'sig/client.rbs', line 417 def get_messaging_session_endpoint: ( |
#get_messaging_streaming_configurations(params = {}) ⇒ Types::GetMessagingStreamingConfigurationsResponse
Retrieves the data streaming configuration for an AppInstance. For
more information, see Streaming messaging data in the Amazon
Chime SDK Developer Guide.
427 |
# File 'sig/client.rbs', line 427 def get_messaging_streaming_configurations: ( |
#list_channel_bans(params = {}) ⇒ Types::ListChannelBansResponse
Lists all the users and bots banned from a particular channel.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
439 |
# File 'sig/client.rbs', line 439 def list_channel_bans: ( |
#list_channel_flows(params = {}) ⇒ Types::ListChannelFlowsResponse
Returns a paginated lists of all the channel flows created under a single Chime. This is a developer API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
453 |
# File 'sig/client.rbs', line 453 def list_channel_flows: ( |
#list_channel_memberships(params = {}) ⇒ Types::ListChannelMembershipsResponse
Lists all channel memberships in a channel.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
If you want to list the channels to which a specific app instance user belongs, see the ListChannelMembershipsForAppInstanceUser API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
467 |
# File 'sig/client.rbs', line 467 def list_channel_memberships: ( |
#list_channel_memberships_for_app_instance_user(params = {}) ⇒ Types::ListChannelMembershipsForAppInstanceUserResponse
Lists all channels that an AppInstanceUser or AppInstanceBot is a
part of. Only an AppInstanceAdmin can call the API with a user ARN
that is not their own.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
483 |
# File 'sig/client.rbs', line 483 def list_channel_memberships_for_app_instance_user: ( |
#list_channel_messages(params = {}) ⇒ Types::ListChannelMessagesResponse
List all the messages in a channel. Returns a paginated list of
ChannelMessages. By default, sorted by creation timestamp in
descending order.
Also, the x-amz-chime-bearer request header is mandatory. Use the
ARN of the AppInstanceUser or AppInstanceBot that makes the API
call as the value in the header.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
499 |
# File 'sig/client.rbs', line 499 def list_channel_messages: ( |
#list_channel_moderators(params = {}) ⇒ Types::ListChannelModeratorsResponse
Lists all the moderators for a channel.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
518 |
# File 'sig/client.rbs', line 518 def list_channel_moderators: ( |
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Lists all Channels created under a single Chime App as a paginated list. You can specify filters to narrow results.
Functionality & restrictions
-
Use privacy =
PUBLICto retrieve all public channels in the account. -
Only an
AppInstanceAdmincan set privacy =PRIVATEto list the private channels in an account.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
532 |
# File 'sig/client.rbs', line 532 def list_channels: ( |
#list_channels_associated_with_channel_flow(params = {}) ⇒ Types::ListChannelsAssociatedWithChannelFlowResponse
Lists all channels associated with a specified channel flow. You can associate a channel flow with multiple channels, but you can only associate a channel with one channel flow. This is a developer API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
547 |
# File 'sig/client.rbs', line 547 def list_channels_associated_with_channel_flow: ( |
#list_channels_moderated_by_app_instance_user(params = {}) ⇒ Types::ListChannelsModeratedByAppInstanceUserResponse
A list of the channels moderated by an AppInstanceUser.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
560 |
# File 'sig/client.rbs', line 560 def list_channels_moderated_by_app_instance_user: ( |
#list_sub_channels(params = {}) ⇒ Types::ListSubChannelsResponse
Lists all the SubChannels in an elastic channel when given a channel ID. Available only to the app instance admins and channel moderators of elastic channels.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
575 |
# File 'sig/client.rbs', line 575 def list_sub_channels: ( |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags applied to an Amazon Chime SDK messaging resource.
588 |
# File 'sig/client.rbs', line 588 def list_tags_for_resource: ( |
#put_channel_expiration_settings(params = {}) ⇒ Types::PutChannelExpirationSettingsResponse
Sets the number of days before the channel is automatically deleted.
-
Expired channels that have not yet been deleted appear as active, and you can update their expiration settings. The system honors the new settings.
-
The
x-amz-chime-bearerrequest header is mandatory. Use the ARN of theAppInstanceUserorAppInstanceBotthat makes the API call as the value in the header.
599 |
# File 'sig/client.rbs', line 599 def put_channel_expiration_settings: ( |
#put_channel_membership_preferences(params = {}) ⇒ Types::PutChannelMembershipPreferencesResponse
Sets the membership preferences of an AppInstanceUser or
AppInstanceBot for the specified channel. The user or bot must be a
member of the channel. Only the user or bot who owns the membership
can set preferences. Users or bots in the AppInstanceAdmin and
channel moderator roles can't set preferences for other users. Banned
users or bots can't set membership preferences for the channel from
which they are banned.
AppInstanceUser or AppInstanceBot that makes the API call as the
value in the header.
616 |
# File 'sig/client.rbs', line 616 def put_channel_membership_preferences: ( |
#put_messaging_streaming_configurations(params = {}) ⇒ Types::PutMessagingStreamingConfigurationsResponse
Sets the data streaming configuration for an AppInstance. For more
information, see Streaming messaging data in the Amazon Chime
SDK Developer Guide.
634 |
# File 'sig/client.rbs', line 634 def put_messaging_streaming_configurations: ( |
#redact_channel_message(params = {}) ⇒ Types::RedactChannelMessageResponse
Redacts message content and metadata. The message exists in the back end, but the action returns null content, and the state shows as redacted.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
652 |
# File 'sig/client.rbs', line 652 def redact_channel_message: ( |
#search_channels(params = {}) ⇒ Types::SearchChannelsResponse
Allows the ChimeBearer to search channels by channel members. Users
or bots can search across the channels that they belong to. Users in
the AppInstanceAdmin role can search across all channels.
The x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
AppInstanceUsers with a large
number of memberships.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
666 |
# File 'sig/client.rbs', line 666 def search_channels: ( |
#send_channel_message(params = {}) ⇒ Types::SendChannelMessageResponse
Sends a message to a particular channel that the member is a part of.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
Also, STANDARD messages can be up to 4KB in size and contain
metadata. Metadata is arbitrary, and you can use it in a variety of
ways, such as containing a link to an attachment.
CONTROL messages are limited to 30 bytes and do not contain
metadata.
688 |
# File 'sig/client.rbs', line 688 def send_channel_message: ( |
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified Amazon Chime SDK messaging resource.
715 |
# File 'sig/client.rbs', line 715 def tag_resource: ( |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified Amazon Chime SDK messaging resource.
727 |
# File 'sig/client.rbs', line 727 def untag_resource: ( |
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Update a channel's attributes.
Restriction: You can't change a channel's privacy.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
738 |
# File 'sig/client.rbs', line 738 def update_channel: ( |
#update_channel_flow(params = {}) ⇒ Types::UpdateChannelFlowResponse
Updates channel flow attributes. This is a developer API.
752 |
# File 'sig/client.rbs', line 752 def update_channel_flow: ( |
#update_channel_message(params = {}) ⇒ Types::UpdateChannelMessageResponse
Updates the content of a message.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
769 |
# File 'sig/client.rbs', line 769 def update_channel_message: ( |
#update_channel_read_marker(params = {}) ⇒ Types::UpdateChannelReadMarkerResponse
The details of the time when a user last read messages in a channel.
x-amz-chime-bearer request header is mandatory. Use the ARN of
the AppInstanceUser or AppInstanceBot that makes the API call as
the value in the header.
785 |
# File 'sig/client.rbs', line 785 def update_channel_read_marker: ( |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3335 3336 3337 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3335 def waiter_names [] end |