Class: Aws::ChimeSDKMessaging::Types::ListChannelMembershipsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ChimeSDKMessaging::Types::ListChannelMembershipsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chimesdkmessaging/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:next_token]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
The maximum number of channel memberships that you want returned.
-
#chime_bearer ⇒ String
The ARN of the
AppInstanceUserorAppInstanceBotthat makes the API call. -
#max_results ⇒ Integer
The maximum number of channel memberships that you want returned.
-
#next_token ⇒ String
The token passed by previous API calls until all requested channel memberships are returned.
-
#sub_channel_id ⇒ String
The ID of the SubChannel in the request.
-
#type ⇒ String
The membership type of a user,
DEFAULTorHIDDEN.
Instance Attribute Details
#channel_arn ⇒ String
The maximum number of channel memberships that you want returned.
2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-chimesdkmessaging/types.rb', line 2137 class ListChannelMembershipsRequest < Struct.new( :channel_arn, :type, :max_results, :next_token, :chime_bearer, :sub_channel_id) SENSITIVE = [:next_token] include Aws::Structure end |
#chime_bearer ⇒ String
The ARN of the AppInstanceUser or AppInstanceBot that makes the
API call.
2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-chimesdkmessaging/types.rb', line 2137 class ListChannelMembershipsRequest < Struct.new( :channel_arn, :type, :max_results, :next_token, :chime_bearer, :sub_channel_id) SENSITIVE = [:next_token] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of channel memberships that you want returned.
2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-chimesdkmessaging/types.rb', line 2137 class ListChannelMembershipsRequest < Struct.new( :channel_arn, :type, :max_results, :next_token, :chime_bearer, :sub_channel_id) SENSITIVE = [:next_token] include Aws::Structure end |
#next_token ⇒ String
The token passed by previous API calls until all requested channel memberships are returned.
2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-chimesdkmessaging/types.rb', line 2137 class ListChannelMembershipsRequest < Struct.new( :channel_arn, :type, :max_results, :next_token, :chime_bearer, :sub_channel_id) SENSITIVE = [:next_token] include Aws::Structure end |
#sub_channel_id ⇒ String
The ID of the SubChannel in the request.
2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-chimesdkmessaging/types.rb', line 2137 class ListChannelMembershipsRequest < Struct.new( :channel_arn, :type, :max_results, :next_token, :chime_bearer, :sub_channel_id) SENSITIVE = [:next_token] include Aws::Structure end |
#type ⇒ String
The membership type of a user, DEFAULT or HIDDEN. Default
members are returned as part of ListChannelMemberships if no type
is specified. Hidden members are only returned if the type filter in
ListChannelMemberships equals HIDDEN.
2137 2138 2139 2140 2141 2142 2143 2144 2145 2146 |
# File 'lib/aws-sdk-chimesdkmessaging/types.rb', line 2137 class ListChannelMembershipsRequest < Struct.new( :channel_arn, :type, :max_results, :next_token, :chime_bearer, :sub_channel_id) SENSITIVE = [:next_token] include Aws::Structure end |