Class: Aws::ChimeSDKMessaging::Types::ListChannelsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::ChimeSDKMessaging::Types::ListChannelsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chimesdkmessaging/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[:next_token]
Instance Attribute Summary collapse
-
#app_instance_arn ⇒ String
The ARN of the
AppInstance. -
#chime_bearer ⇒ String
The ARN of the
AppInstanceUserorAppInstanceBotthat makes the API call. -
#max_results ⇒ Integer
The maximum number of channels that you want to return.
-
#next_token ⇒ String
The token passed by previous API calls until all requested channels are returned.
-
#privacy ⇒ String
The privacy setting.
Instance Attribute Details
#app_instance_arn ⇒ String
The ARN of the AppInstance.
2420 2421 2422 2423 2424 2425 2426 2427 2428 |
# File 'lib/aws-sdk-chimesdkmessaging/types.rb', line 2420 class ListChannelsRequest < Struct.new( :app_instance_arn, :privacy, :max_results, :next_token, :chime_bearer) SENSITIVE = [:next_token] include Aws::Structure end |
#chime_bearer ⇒ String
The ARN of the AppInstanceUser or AppInstanceBot that makes the
API call.
2420 2421 2422 2423 2424 2425 2426 2427 2428 |
# File 'lib/aws-sdk-chimesdkmessaging/types.rb', line 2420 class ListChannelsRequest < Struct.new( :app_instance_arn, :privacy, :max_results, :next_token, :chime_bearer) SENSITIVE = [:next_token] include Aws::Structure end |
#max_results ⇒ Integer
The maximum number of channels that you want to return.
2420 2421 2422 2423 2424 2425 2426 2427 2428 |
# File 'lib/aws-sdk-chimesdkmessaging/types.rb', line 2420 class ListChannelsRequest < Struct.new( :app_instance_arn, :privacy, :max_results, :next_token, :chime_bearer) SENSITIVE = [:next_token] include Aws::Structure end |
#next_token ⇒ String
The token passed by previous API calls until all requested channels are returned.
2420 2421 2422 2423 2424 2425 2426 2427 2428 |
# File 'lib/aws-sdk-chimesdkmessaging/types.rb', line 2420 class ListChannelsRequest < Struct.new( :app_instance_arn, :privacy, :max_results, :next_token, :chime_bearer) SENSITIVE = [:next_token] include Aws::Structure end |
#privacy ⇒ String
The privacy setting. PUBLIC retrieves all the public channels.
PRIVATE retrieves private channels. Only an AppInstanceAdmin can
retrieve private channels.
2420 2421 2422 2423 2424 2425 2426 2427 2428 |
# File 'lib/aws-sdk-chimesdkmessaging/types.rb', line 2420 class ListChannelsRequest < Struct.new( :app_instance_arn, :privacy, :max_results, :next_token, :chime_bearer) SENSITIVE = [:next_token] include Aws::Structure end |