Class: Aws::ChimeSDKMessaging::Types::Target
- Inherits:
-
Struct
- Object
- Struct
- Aws::ChimeSDKMessaging::Types::Target
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-chimesdkmessaging/types.rb
Overview
The target of a message, a sender, a user, or a bot. Only the target and the sender can view targeted messages. Only users who can see targeted messages can take actions on them. However, administrators can delete targeted messages that they can’t see.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#member_arn ⇒ String
The ARN of the target channel member.
Instance Attribute Details
#member_arn ⇒ String
The ARN of the target channel member.
3183 3184 3185 3186 3187 |
# File 'lib/aws-sdk-chimesdkmessaging/types.rb', line 3183 class Target < Struct.new( :member_arn) SENSITIVE = [] include Aws::Structure end |