Class: Aws::ChimeSDKMessaging::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::ChimeSDKMessaging::Client
- Includes:
- Aws::ClientStubs
- Defined in:
- lib/aws-sdk-chimesdkmessaging/client.rb
Overview
An API client for ChimeSDKMessaging. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::ChimeSDKMessaging::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#associate_channel_flow(params = {}) ⇒ Struct
Associates a channel flow with a channel.
-
#batch_create_channel_membership(params = {}) ⇒ Types::BatchCreateChannelMembershipResponse
Adds a specified number of users and bots to a channel.
-
#channel_flow_callback(params = {}) ⇒ Types::ChannelFlowCallbackResponse
Calls back Amazon Chime SDK messaging with a processing response message.
-
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a channel to which you can add users and send messages.
-
#create_channel_ban(params = {}) ⇒ Types::CreateChannelBanResponse
Permanently bans a member from a channel.
-
#create_channel_flow(params = {}) ⇒ Types::CreateChannelFlowResponse
Creates a channel flow, a container for processors.
-
#create_channel_membership(params = {}) ⇒ Types::CreateChannelMembershipResponse
Adds a member to a channel.
-
#create_channel_moderator(params = {}) ⇒ Types::CreateChannelModeratorResponse
Creates a new ‘ChannelModerator`.
-
#delete_channel(params = {}) ⇒ Struct
Immediately makes a channel and its memberships inaccessible and marks them for deletion.
-
#delete_channel_ban(params = {}) ⇒ Struct
Removes a member from a channel’s ban list.
-
#delete_channel_flow(params = {}) ⇒ Struct
Deletes a channel flow, an irreversible process.
-
#delete_channel_membership(params = {}) ⇒ Struct
Removes a member from a channel.
-
#delete_channel_message(params = {}) ⇒ Struct
Deletes a channel message.
-
#delete_channel_moderator(params = {}) ⇒ Struct
Deletes a channel moderator.
-
#delete_messaging_streaming_configurations(params = {}) ⇒ Struct
Deletes the streaming configurations for an ‘AppInstance`.
-
#describe_channel(params = {}) ⇒ Types::DescribeChannelResponse
Returns the full details of a channel in an Amazon Chime ‘AppInstance`.
-
#describe_channel_ban(params = {}) ⇒ Types::DescribeChannelBanResponse
Returns the full details of a channel ban.
-
#describe_channel_flow(params = {}) ⇒ Types::DescribeChannelFlowResponse
Returns the full details of a channel flow in an Amazon Chime ‘AppInstance`.
-
#describe_channel_membership(params = {}) ⇒ Types::DescribeChannelMembershipResponse
Returns the full details of a user’s channel membership.
-
#describe_channel_membership_for_app_instance_user(params = {}) ⇒ Types::DescribeChannelMembershipForAppInstanceUserResponse
Returns the details of a channel based on the membership of the specified ‘AppInstanceUser` or `AppInstanceBot`.
-
#describe_channel_moderated_by_app_instance_user(params = {}) ⇒ Types::DescribeChannelModeratedByAppInstanceUserResponse
Returns the full details of a channel moderated by the specified ‘AppInstanceUser` or `AppInstanceBot`.
-
#describe_channel_moderator(params = {}) ⇒ Types::DescribeChannelModeratorResponse
Returns the full details of a single ChannelModerator.
-
#disassociate_channel_flow(params = {}) ⇒ Struct
Disassociates a channel flow from all its channels.
-
#get_channel_membership_preferences(params = {}) ⇒ Types::GetChannelMembershipPreferencesResponse
Gets the membership preferences of an ‘AppInstanceUser` or `AppInstanceBot` for the specified channel.
-
#get_channel_message(params = {}) ⇒ Types::GetChannelMessageResponse
Gets the full details of a channel message.
-
#get_channel_message_status(params = {}) ⇒ Types::GetChannelMessageStatusResponse
Gets message status for a specified ‘messageId`.
-
#get_messaging_session_endpoint(params = {}) ⇒ Types::GetMessagingSessionEndpointResponse
The details of the endpoint for the messaging session.
-
#get_messaging_streaming_configurations(params = {}) ⇒ Types::GetMessagingStreamingConfigurationsResponse
Retrieves the data streaming configuration for an ‘AppInstance`.
-
#list_channel_bans(params = {}) ⇒ Types::ListChannelBansResponse
Lists all the users and bots banned from a particular channel.
-
#list_channel_flows(params = {}) ⇒ Types::ListChannelFlowsResponse
Returns a paginated lists of all the channel flows created under a single Chime.
-
#list_channel_memberships(params = {}) ⇒ Types::ListChannelMembershipsResponse
Lists all channel memberships in a channel.
-
#list_channel_memberships_for_app_instance_user(params = {}) ⇒ Types::ListChannelMembershipsForAppInstanceUserResponse
Lists all channels that an ‘AppInstanceUser` or `AppInstanceBot` is a part of.
-
#list_channel_messages(params = {}) ⇒ Types::ListChannelMessagesResponse
List all the messages in a channel.
-
#list_channel_moderators(params = {}) ⇒ Types::ListChannelModeratorsResponse
Lists all the moderators for a channel.
-
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Lists all Channels created under a single Chime App as a paginated list.
-
#list_channels_associated_with_channel_flow(params = {}) ⇒ Types::ListChannelsAssociatedWithChannelFlowResponse
Lists all channels associated with a specified channel flow.
-
#list_channels_moderated_by_app_instance_user(params = {}) ⇒ Types::ListChannelsModeratedByAppInstanceUserResponse
A list of the channels moderated by an ‘AppInstanceUser`.
-
#list_sub_channels(params = {}) ⇒ Types::ListSubChannelsResponse
Lists all the SubChannels in an elastic channel when given a channel ID.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags applied to an Amazon Chime SDK messaging resource.
-
#put_channel_expiration_settings(params = {}) ⇒ Types::PutChannelExpirationSettingsResponse
Sets the number of days before the channel is automatically deleted.
-
#put_channel_membership_preferences(params = {}) ⇒ Types::PutChannelMembershipPreferencesResponse
Sets the membership preferences of an ‘AppInstanceUser` or `AppInstanceBot` for the specified channel.
-
#put_messaging_streaming_configurations(params = {}) ⇒ Types::PutMessagingStreamingConfigurationsResponse
Sets the data streaming configuration for an ‘AppInstance`.
-
#redact_channel_message(params = {}) ⇒ Types::RedactChannelMessageResponse
Redacts message content and metadata.
-
#search_channels(params = {}) ⇒ Types::SearchChannelsResponse
Allows the ‘ChimeBearer` to search channels by channel members.
-
#send_channel_message(params = {}) ⇒ Types::SendChannelMessageResponse
Sends a message to a particular channel that the member is a part of.
-
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified Amazon Chime SDK messaging resource.
-
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified Amazon Chime SDK messaging resource.
-
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Update a channel’s attributes.
-
#update_channel_flow(params = {}) ⇒ Types::UpdateChannelFlowResponse
Updates channel flow attributes.
-
#update_channel_message(params = {}) ⇒ Types::UpdateChannelMessageResponse
Updates the content of a message.
-
#update_channel_read_marker(params = {}) ⇒ Types::UpdateChannelReadMarkerResponse
The details of the time when a user last read messages in a channel.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3342 3343 3344 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3342 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3345 3346 3347 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3345 def errors_module Errors end |
Instance Method Details
#associate_channel_flow(params = {}) ⇒ Struct
Associates a channel flow with a channel. Once associated, all messages to that channel go through channel flow processors. To stop processing, use the ‘DisassociateChannelFlow` API.
<note markdown=“1”> Only administrators or channel moderators can associate a channel flow. The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
511 512 513 514 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 511 def associate_channel_flow(params = {}, = {}) req = build_request(:associate_channel_flow, params) req.send_request() end |
#batch_create_channel_membership(params = {}) ⇒ Types::BatchCreateChannelMembershipResponse
Adds a specified number of users and bots to a channel.
579 580 581 582 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 579 def batch_create_channel_membership(params = {}, = {}) req = build_request(:batch_create_channel_membership, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3315 3316 3317 3318 3319 3320 3321 3322 3323 3324 3325 3326 3327 3328 3329 3330 3331 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3315 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::ChimeSDKMessaging') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-chimesdkmessaging' context[:gem_version] = '1.65.0' Seahorse::Client::Request.new(handlers, context) end |
#channel_flow_callback(params = {}) ⇒ Types::ChannelFlowCallbackResponse
Calls back Amazon Chime SDK messaging with a processing response message. This should be invoked from the processor Lambda. This is a developer API.
You can return one of the following processing responses:
-
Update message content or metadata
-
Deny a message
-
Make no changes to the message
652 653 654 655 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 652 def channel_flow_callback(params = {}, = {}) req = build_request(:channel_flow_callback, params) req.send_request() end |
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a channel to which you can add users and send messages.
Restriction: You can’t change a channel’s privacy.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
761 762 763 764 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 761 def create_channel(params = {}, = {}) req = build_request(:create_channel, params) req.send_request() end |
#create_channel_ban(params = {}) ⇒ Types::CreateChannelBanResponse
Permanently bans a member from a channel. Moderators can’t add banned members to a channel. To undo a ban, you first have to ‘DeleteChannelBan`, and then `CreateChannelMembership`. Bans are cleaned up when you delete users or channels.
If you ban a user who is already part of a channel, that user is automatically kicked from the channel.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
813 814 815 816 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 813 def create_channel_ban(params = {}, = {}) req = build_request(:create_channel_ban, params) req.send_request() end |
#create_channel_flow(params = {}) ⇒ Types::CreateChannelFlowResponse
Creates a channel flow, a container for processors. Processors are AWS Lambda functions that perform actions on chat messages, such as stripping out profanity. You can associate channel flows with channels, and the processors in the channel flow then take action on all messages sent to that channel. This is a developer API.
Channel flows process the following items:
-
New and updated messages
-
Persistent and non-persistent messages
-
The Standard message type
<note markdown=“1”> Channel flows don’t process Control or System messages. For more information about the message types provided by Chime SDK messaging, refer to [Message types] in the *Amazon Chime developer guide*.
</note>
[1]: docs.aws.amazon.com/chime-sdk/latest/dg/using-the-messaging-sdk.html#msg-types
899 900 901 902 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 899 def create_channel_flow(params = {}, = {}) req = build_request(:create_channel_flow, params) req.send_request() end |
#create_channel_membership(params = {}) ⇒ Types::CreateChannelMembershipResponse
Adds a member to a channel. The ‘InvitedBy` field in `ChannelMembership` is derived from the request header. A channel member can:
-
List messages
-
Send messages
-
Receive messages
-
Edit their own messages
-
Leave the channel
Privacy settings impact this action as follows:
-
Public Channels: You do not need to be a member to list messages, but you must be a member to send messages.
-
Private Channels: You must be a member to list or send messages.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUserArn` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
983 984 985 986 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 983 def create_channel_membership(params = {}, = {}) req = build_request(:create_channel_membership, params) req.send_request() end |
#create_channel_moderator(params = {}) ⇒ Types::CreateChannelModeratorResponse
Creates a new ‘ChannelModerator`. A channel moderator can:
-
Add and remove other members of the channel.
-
Add and remove other moderators of the channel.
-
Add and remove user bans for the channel.
-
Redact messages in the channel.
-
List messages in the channel.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot`of the user that makes the API call as the value in the header.
</note>
1039 1040 1041 1042 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1039 def create_channel_moderator(params = {}, = {}) req = build_request(:create_channel_moderator, params) req.send_request() end |
#delete_channel(params = {}) ⇒ Struct
Immediately makes a channel and its memberships inaccessible and marks them for deletion. This is an irreversible process.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUserArn` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1073 1074 1075 1076 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1073 def delete_channel(params = {}, = {}) req = build_request(:delete_channel, params) req.send_request() end |
#delete_channel_ban(params = {}) ⇒ Struct
Removes a member from a channel’s ban list.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1110 1111 1112 1113 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1110 def delete_channel_ban(params = {}, = {}) req = build_request(:delete_channel_ban, params) req.send_request() end |
#delete_channel_flow(params = {}) ⇒ Struct
Deletes a channel flow, an irreversible process. This is a developer API.
<note markdown=“1”> This API works only when the channel flow is not associated with any channel. To get a list of all channels that a channel flow is associated with, use the ‘ListChannelsAssociatedWithChannelFlow` API. Use the `DisassociateChannelFlow` API to disassociate a channel flow from all channels.
</note>
1141 1142 1143 1144 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1141 def delete_channel_flow(params = {}, = {}) req = build_request(:delete_channel_flow, params) req.send_request() end |
#delete_channel_membership(params = {}) ⇒ Struct
Removes a member from a channel.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the `AppInstanceUserArn` of the user that makes the API call as the value in the header.
</note>
1187 1188 1189 1190 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1187 def delete_channel_membership(params = {}, = {}) req = build_request(:delete_channel_membership, params) req.send_request() end |
#delete_channel_message(params = {}) ⇒ Struct
Deletes a channel message. Only admins can perform this action. Deletion makes messages inaccessible immediately. A background process deletes any revisions created by ‘UpdateChannelMessage`.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1235 1236 1237 1238 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1235 def (params = {}, = {}) req = build_request(:delete_channel_message, params) req.send_request() end |
#delete_channel_moderator(params = {}) ⇒ Struct
Deletes a channel moderator.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1272 1273 1274 1275 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1272 def delete_channel_moderator(params = {}, = {}) req = build_request(:delete_channel_moderator, params) req.send_request() end |
#delete_messaging_streaming_configurations(params = {}) ⇒ Struct
Deletes the streaming configurations for an ‘AppInstance`. For more information, see [Streaming messaging data] in the *Amazon Chime SDK Developer Guide*.
[1]: docs.aws.amazon.com/chime-sdk/latest/dg/streaming-export.html
1300 1301 1302 1303 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1300 def delete_messaging_streaming_configurations(params = {}, = {}) req = build_request(:delete_messaging_streaming_configurations, params) req.send_request() end |
#describe_channel(params = {}) ⇒ Types::DescribeChannelResponse
Returns the full details of a channel in an Amazon Chime ‘AppInstance`.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1355 1356 1357 1358 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1355 def describe_channel(params = {}, = {}) req = build_request(:describe_channel, params) req.send_request() end |
#describe_channel_ban(params = {}) ⇒ Types::DescribeChannelBanResponse
Returns the full details of a channel ban.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1403 1404 1405 1406 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1403 def describe_channel_ban(params = {}, = {}) req = build_request(:describe_channel_ban, params) req.send_request() end |
#describe_channel_flow(params = {}) ⇒ Types::DescribeChannelFlowResponse
Returns the full details of a channel flow in an Amazon Chime ‘AppInstance`. This is a developer API.
1441 1442 1443 1444 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1441 def describe_channel_flow(params = {}, = {}) req = build_request(:describe_channel_flow, params) req.send_request() end |
#describe_channel_membership(params = {}) ⇒ Types::DescribeChannelMembershipResponse
Returns the full details of a user’s channel membership.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1501 1502 1503 1504 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1501 def describe_channel_membership(params = {}, = {}) req = build_request(:describe_channel_membership, params) req.send_request() end |
#describe_channel_membership_for_app_instance_user(params = {}) ⇒ Types::DescribeChannelMembershipForAppInstanceUserResponse
Returns the details of a channel based on the membership of the specified ‘AppInstanceUser` or `AppInstanceBot`.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1553 1554 1555 1556 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1553 def describe_channel_membership_for_app_instance_user(params = {}, = {}) req = build_request(:describe_channel_membership_for_app_instance_user, params) req.send_request() end |
#describe_channel_moderated_by_app_instance_user(params = {}) ⇒ Types::DescribeChannelModeratedByAppInstanceUserResponse
Returns the full details of a channel moderated by the specified ‘AppInstanceUser` or `AppInstanceBot`.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1602 1603 1604 1605 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1602 def describe_channel_moderated_by_app_instance_user(params = {}, = {}) req = build_request(:describe_channel_moderated_by_app_instance_user, params) req.send_request() end |
#describe_channel_moderator(params = {}) ⇒ Types::DescribeChannelModeratorResponse
Returns the full details of a single ChannelModerator.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the `AppInstanceUserArn` of the user that makes the API call as the value in the header.
</note>
1650 1651 1652 1653 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1650 def describe_channel_moderator(params = {}, = {}) req = build_request(:describe_channel_moderator, params) req.send_request() end |
#disassociate_channel_flow(params = {}) ⇒ Struct
Disassociates a channel flow from all its channels. Once disassociated, all messages to that channel stop going through the channel flow processor.
<note markdown=“1”> Only administrators or channel moderators can disassociate a channel flow.
The `x-amz-chime-bearer` request header is mandatory. Use the ARN of
the ‘AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1691 1692 1693 1694 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1691 def disassociate_channel_flow(params = {}, = {}) req = build_request(:disassociate_channel_flow, params) req.send_request() end |
#get_channel_membership_preferences(params = {}) ⇒ Types::GetChannelMembershipPreferencesResponse
Gets the membership preferences of an ‘AppInstanceUser` or `AppInstanceBot` for the specified channel. A user or a bot must be a member of the channel and own the membership in order to retrieve membership preferences. Users or bots in the `AppInstanceAdmin` and channel moderator roles can’t retrieve preferences for other users or bots. Banned users or bots can’t retrieve membership preferences for the channel from which they are banned.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1746 1747 1748 1749 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1746 def get_channel_membership_preferences(params = {}, = {}) req = build_request(:get_channel_membership_preferences, params) req.send_request() end |
#get_channel_message(params = {}) ⇒ Types::GetChannelMessageResponse
Gets the full details of a channel message.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1818 1819 1820 1821 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1818 def (params = {}, = {}) req = build_request(:get_channel_message, params) req.send_request() end |
#get_channel_message_status(params = {}) ⇒ Types::GetChannelMessageStatusResponse
Gets message status for a specified ‘messageId`. Use this API to determine the intermediate status of messages going through channel flow processing. The API provides an alternative to retrieving message status if the event was not received because a client wasn’t connected to a websocket.
Messages can have any one of these statuses.
SENT
: Message processed successfully
PENDING
: Ongoing processing
FAILED
: Processing failed
DENIED
: Message denied by the processor
<note markdown=“1”> * This API does not return statuses for denied messages, because we
don't store them once the processor denies them.
-
Only the message sender can invoke this API.
-
The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
1897 1898 1899 1900 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1897 def (params = {}, = {}) req = build_request(:get_channel_message_status, params) req.send_request() end |
#get_messaging_session_endpoint(params = {}) ⇒ Types::GetMessagingSessionEndpointResponse
The details of the endpoint for the messaging session.
1926 1927 1928 1929 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1926 def get_messaging_session_endpoint(params = {}, = {}) req = build_request(:get_messaging_session_endpoint, params) req.send_request() end |
#get_messaging_streaming_configurations(params = {}) ⇒ Types::GetMessagingStreamingConfigurationsResponse
Retrieves the data streaming configuration for an ‘AppInstance`. For more information, see [Streaming messaging data] in the *Amazon Chime SDK Developer Guide*.
[1]: docs.aws.amazon.com/chime-sdk/latest/dg/streaming-export.html
1962 1963 1964 1965 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 1962 def get_messaging_streaming_configurations(params = {}, = {}) req = build_request(:get_messaging_streaming_configurations, params) req.send_request() end |
#list_channel_bans(params = {}) ⇒ Types::ListChannelBansResponse
Lists all the users and bots banned from a particular channel.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2018 2019 2020 2021 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2018 def list_channel_bans(params = {}, = {}) req = build_request(:list_channel_bans, params) req.send_request() end |
#list_channel_flows(params = {}) ⇒ Types::ListChannelFlowsResponse
Returns a paginated lists of all the channel flows created under a single Chime. This is a developer API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2068 2069 2070 2071 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2068 def list_channel_flows(params = {}, = {}) req = build_request(:list_channel_flows, params) req.send_request() end |
#list_channel_memberships(params = {}) ⇒ Types::ListChannelMembershipsResponse
Lists all channel memberships in a channel.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
If you want to list the channels to which a specific app instance user belongs, see the [ListChannelMembershipsForAppInstanceUser] API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2147 2148 2149 2150 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2147 def list_channel_memberships(params = {}, = {}) req = build_request(:list_channel_memberships, params) req.send_request() end |
#list_channel_memberships_for_app_instance_user(params = {}) ⇒ Types::ListChannelMembershipsForAppInstanceUserResponse
Lists all channels that an ‘AppInstanceUser` or `AppInstanceBot` is a part of. Only an `AppInstanceAdmin` can call the API with a user ARN that is not their own.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2210 2211 2212 2213 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2210 def list_channel_memberships_for_app_instance_user(params = {}, = {}) req = build_request(:list_channel_memberships_for_app_instance_user, params) req.send_request() end |
#list_channel_messages(params = {}) ⇒ Types::ListChannelMessagesResponse
List all the messages in a channel. Returns a paginated list of ‘ChannelMessages`. By default, sorted by creation timestamp in descending order.
<note markdown=“1”> Redacted messages appear in the results as empty, since they are only redacted, not deleted. Deleted messages do not appear in the results. This action always returns the latest version of an edited message.
Also, the `x-amz-chime-bearer` request header is mandatory. Use the
ARN of the ‘AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2312 2313 2314 2315 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2312 def (params = {}, = {}) req = build_request(:list_channel_messages, params) req.send_request() end |
#list_channel_moderators(params = {}) ⇒ Types::ListChannelModeratorsResponse
Lists all the moderators for a channel.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2368 2369 2370 2371 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2368 def list_channel_moderators(params = {}, = {}) req = build_request(:list_channel_moderators, params) req.send_request() end |
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Lists all Channels created under a single Chime App as a paginated list. You can specify filters to narrow results.
**Functionality & restrictions**
-
Use privacy = ‘PUBLIC` to retrieve all public channels in the account.
-
Only an ‘AppInstanceAdmin` can set privacy = `PRIVATE` to list the private channels in an account.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2441 2442 2443 2444 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2441 def list_channels(params = {}, = {}) req = build_request(:list_channels, params) req.send_request() end |
#list_channels_associated_with_channel_flow(params = {}) ⇒ Types::ListChannelsAssociatedWithChannelFlowResponse
Lists all channels associated with a specified channel flow. You can associate a channel flow with multiple channels, but you can only associate a channel with one channel flow. This is a developer API.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2489 2490 2491 2492 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2489 def list_channels_associated_with_channel_flow(params = {}, = {}) req = build_request(:list_channels_associated_with_channel_flow, params) req.send_request() end |
#list_channels_moderated_by_app_instance_user(params = {}) ⇒ Types::ListChannelsModeratedByAppInstanceUserResponse
A list of the channels moderated by an ‘AppInstanceUser`.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2547 2548 2549 2550 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2547 def list_channels_moderated_by_app_instance_user(params = {}, = {}) req = build_request(:list_channels_moderated_by_app_instance_user, params) req.send_request() end |
#list_sub_channels(params = {}) ⇒ Types::ListSubChannelsResponse
Lists all the SubChannels in an elastic channel when given a channel ID. Available only to the app instance admins and channel moderators of elastic channels.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2598 2599 2600 2601 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2598 def list_sub_channels(params = {}, = {}) req = build_request(:list_sub_channels, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Lists the tags applied to an Amazon Chime SDK messaging resource.
2628 2629 2630 2631 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2628 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_channel_expiration_settings(params = {}) ⇒ Types::PutChannelExpirationSettingsResponse
Sets the number of days before the channel is automatically deleted.
<note markdown=“1”> * A background process deletes expired channels within 6 hours of
expiration. Actual deletion times may vary.
-
Expired channels that have not yet been deleted appear as active, and you can update their expiration settings. The system honors the new settings.
-
The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
2684 2685 2686 2687 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2684 def put_channel_expiration_settings(params = {}, = {}) req = build_request(:put_channel_expiration_settings, params) req.send_request() end |
#put_channel_membership_preferences(params = {}) ⇒ Types::PutChannelMembershipPreferencesResponse
Sets the membership preferences of an ‘AppInstanceUser` or `AppInstanceBot` for the specified channel. The user or bot must be a member of the channel. Only the user or bot who owns the membership can set preferences. Users or bots in the `AppInstanceAdmin` and channel moderator roles can’t set preferences for other users. Banned users or bots can’t set membership preferences for the channel from which they are banned.
<note markdown=“1”> The x-amz-chime-bearer request header is mandatory. Use the ARN of an ‘AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
2748 2749 2750 2751 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2748 def put_channel_membership_preferences(params = {}, = {}) req = build_request(:put_channel_membership_preferences, params) req.send_request() end |
#put_messaging_streaming_configurations(params = {}) ⇒ Types::PutMessagingStreamingConfigurationsResponse
Sets the data streaming configuration for an ‘AppInstance`. For more information, see [Streaming messaging data] in the *Amazon Chime SDK Developer Guide*.
[1]: docs.aws.amazon.com/chime-sdk/latest/dg/streaming-export.html
2793 2794 2795 2796 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2793 def put_messaging_streaming_configurations(params = {}, = {}) req = build_request(:put_messaging_streaming_configurations, params) req.send_request() end |
#redact_channel_message(params = {}) ⇒ Types::RedactChannelMessageResponse
Redacts message content and metadata. The message exists in the back end, but the action returns null content, and the state shows as redacted.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
2847 2848 2849 2850 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2847 def (params = {}, = {}) req = build_request(:redact_channel_message, params) req.send_request() end |
#search_channels(params = {}) ⇒ Types::SearchChannelsResponse
Allows the ‘ChimeBearer` to search channels by channel members. Users or bots can search across the channels that they belong to. Users in the `AppInstanceAdmin` role can search across all channels.
The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
<note markdown=“1”> This operation isn’t supported for ‘AppInstanceUsers` with a large number of memberships.
</note>
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2915 2916 2917 2918 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 2915 def search_channels(params = {}, = {}) req = build_request(:search_channels, params) req.send_request() end |
#send_channel_message(params = {}) ⇒ Types::SendChannelMessageResponse
Sends a message to a particular channel that the member is a part of.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
Also, `STANDARD` messages can be up to 4KB in size and contain
metadata. Metadata is arbitrary, and you can use it in a variety of ways, such as containing a link to an attachment.
`CONTROL` messages are limited to 30 bytes and do not contain
metadata.
</note>
3036 3037 3038 3039 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3036 def (params = {}, = {}) req = build_request(:send_channel_message, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Applies the specified tags to the specified Amazon Chime SDK messaging resource.
3068 3069 3070 3071 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3068 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes the specified tags from the specified Amazon Chime SDK messaging resource.
3095 3096 3097 3098 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3095 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Update a channel’s attributes.
Restriction: You can’t change a channel’s privacy.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
3148 3149 3150 3151 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3148 def update_channel(params = {}, = {}) req = build_request(:update_channel, params) req.send_request() end |
#update_channel_flow(params = {}) ⇒ Types::UpdateChannelFlowResponse
Updates channel flow attributes. This is a developer API.
3196 3197 3198 3199 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3196 def update_channel_flow(params = {}, = {}) req = build_request(:update_channel_flow, params) req.send_request() end |
#update_channel_message(params = {}) ⇒ Types::UpdateChannelMessageResponse
Updates the content of a message.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
3267 3268 3269 3270 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3267 def (params = {}, = {}) req = build_request(:update_channel_message, params) req.send_request() end |
#update_channel_read_marker(params = {}) ⇒ Types::UpdateChannelReadMarkerResponse
The details of the time when a user last read messages in a channel.
<note markdown=“1”> The ‘x-amz-chime-bearer` request header is mandatory. Use the ARN of the `AppInstanceUser` or `AppInstanceBot` that makes the API call as the value in the header.
</note>
3306 3307 3308 3309 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3306 def update_channel_read_marker(params = {}, = {}) req = build_request(:update_channel_read_marker, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
3335 3336 3337 |
# File 'lib/aws-sdk-chimesdkmessaging/client.rb', line 3335 def waiter_names [] end |